@@ -11,14 +11,8 @@
 # OF ANY KIND, either express or implied. See the License for the
 # specific language governing permissions and limitations under the
 # License.
-
-# Python 2/3 compatibility
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 __author__ = 'Amazon.com, Inc.'
-__version__ = '0.9.3'
+__version__ = '0.10.0'
 
 __all__ = [
     'core',
