@@ -14,11 +14,6 @@
 
 """Exceptions for Ion Python."""
 
-# Python 2/3 compatibility
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 
 class IonException(Exception):
     """Root exception for Ion Python."""
