@@ -13,20 +13,12 @@
 # License.
 
 """Provides a ``simplejson``-like API for dumping and loading Ion data."""
-
-# Python 2/3 compatibility
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
+import io
 from datetime import datetime
 from decimal import Decimal
 from io import BytesIO, TextIOBase
-from itertools import chain
 from types import GeneratorType
 
-import six
-
 from amazon.ion.reader_text import text_reader
 from amazon.ion.writer_text import text_writer
 from .core import IonEvent, IonEventType, IonType, ION_STREAM_END_EVENT, Timestamp, ION_VERSION_MARKER_EVENT
@@ -47,17 +39,19 @@ try:
 except ModuleNotFoundError:
     c_ext = False
 
-
 _ION_CONTAINER_END_EVENT = IonEvent(IonEventType.CONTAINER_END)
 _IVM = b'\xe0\x01\x00\xea'
-_TEXT_TYPES = (TextIOBase, six.StringIO)
+_TEXT_TYPES = (TextIOBase, io.StringIO)
 
 
 def dump_python(obj, fp, imports=None, binary=True, sequence_as_stream=False, skipkeys=False, ensure_ascii=True,
-         check_circular=True, allow_nan=True, cls=None, indent=None, separators=None, encoding='utf-8', default=None,
-         use_decimal=True, namedtuple_as_object=True, tuple_as_array=True, bigint_as_string=False, sort_keys=False,
-         item_sort_key=None, for_json=None, ignore_nan=False, int_as_string_bitcount=None, iterable_as_array=False,
-         tuple_as_sexp=False, omit_version_marker=False, **kw):
+                check_circular=True, allow_nan=True, cls=None, indent=None, separators=None, encoding='utf-8',
+                default=None,
+                use_decimal=True, namedtuple_as_object=True, tuple_as_array=True, bigint_as_string=False,
+                sort_keys=False,
+                item_sort_key=None, for_json=None, ignore_nan=False, int_as_string_bitcount=None,
+                iterable_as_array=False,
+                tuple_as_sexp=False, omit_version_marker=False, **kw):
     """Serialize ``obj`` as an Ion-formatted stream to ``fp`` (a file-like object), using the following conversion
     table::
         +-------------------+-------------------+
@@ -166,26 +160,22 @@ def dump_python(obj, fp, imports=None, binary=True, sequence_as_stream=False, sk
     writer.send(ION_STREAM_END_EVENT)
 
 
-_FROM_TYPE = dict(chain(
-    six.iteritems({
-        type(None): IonType.NULL,
-        type(True): IonType.BOOL,
-        type(False): IonType.BOOL,
-        float: IonType.FLOAT,
-        six.text_type: IonType.STRING,
-        Decimal: IonType.DECIMAL,
-        datetime: IonType.TIMESTAMP,
-        Timestamp: IonType.TIMESTAMP,
-        six.binary_type: IonType.BLOB,
-        SymbolToken: IonType.SYMBOL,
-        list: IonType.LIST,
-        tuple: IonType.LIST,
-        dict: IonType.STRUCT
-    }),
-    six.iteritems(
-        dict(zip(six.integer_types, [IonType.INT] * len(six.integer_types)))
-    ),
-))
+_FROM_TYPE = {
+    type(None): IonType.NULL,
+    type(True): IonType.BOOL,
+    type(False): IonType.BOOL,
+    float: IonType.FLOAT,
+    str: IonType.STRING,
+    Decimal: IonType.DECIMAL,
+    datetime: IonType.TIMESTAMP,
+    Timestamp: IonType.TIMESTAMP,
+    bytes: IonType.BLOB,
+    SymbolToken: IonType.SYMBOL,
+    list: IonType.LIST,
+    tuple: IonType.LIST,
+    dict: IonType.STRUCT,
+    int: IonType.INT
+}
 
 _FROM_TYPE_TUPLE_AS_SEXP = dict(_FROM_TYPE)
 _FROM_TYPE_TUPLE_AS_SEXP.update({
@@ -225,11 +215,11 @@ def _dump(obj, writer, from_type, field=None, in_struct=False, depth=0):
             event = IonEvent(IonEventType.CONTAINER_START, ion_type, field_name=field, depth=depth)
         writer.send(event)
         if ion_type is IonType.STRUCT:
-            for field, val in six.iteritems(obj):
-                _dump(val, writer, from_type, field, in_struct=True, depth=depth+1)
+            for field, val in iter(obj.items()):
+                _dump(val, writer, from_type, field, in_struct=True, depth=depth + 1)
         else:
             for elem in obj:
-                _dump(elem, writer, from_type, depth=depth+1)
+                _dump(elem, writer, from_type, depth=depth + 1)
         event = _ION_CONTAINER_END_EVENT
     else:
         # obj is a scalar value
@@ -240,7 +230,8 @@ def _dump(obj, writer, from_type, field=None, in_struct=False, depth=0):
     writer.send(event)
 
 
-def dumps(obj, imports=None, binary=True, sequence_as_stream=False, skipkeys=False, ensure_ascii=True, check_circular=True,
+def dumps(obj, imports=None, binary=True, sequence_as_stream=False, skipkeys=False, ensure_ascii=True,
+          check_circular=True,
           allow_nan=True, cls=None, indent=None, separators=None, encoding='utf-8', default=None, use_decimal=True,
           namedtuple_as_object=True, tuple_as_array=True, bigint_as_string=False, sort_keys=False, item_sort_key=None,
           for_json=None, ignore_nan=False, int_as_string_bitcount=None, iterable_as_array=False, tuple_as_sexp=False,
@@ -287,7 +278,7 @@ def dumps(obj, imports=None, binary=True, sequence_as_stream=False, skipkeys=Fal
         Union[str|bytes]: The string or binary representation of the data.  if ``binary=True``, this will be a
             ``bytes`` object, otherwise this will be a ``str`` object (or ``unicode`` in the case of Python 2.x)
     """
-    ion_buffer = six.BytesIO()
+    ion_buffer = io.BytesIO()
 
     dump(obj, ion_buffer, imports=imports, sequence_as_stream=sequence_as_stream, binary=binary, skipkeys=skipkeys,
          ensure_ascii=ensure_ascii, check_circular=check_circular,
@@ -305,7 +296,8 @@ def dumps(obj, imports=None, binary=True, sequence_as_stream=False, skipkeys=Fal
 
 
 def load_python(fp, catalog=None, single_value=True, encoding='utf-8', cls=None, object_hook=None, parse_float=None,
-        parse_int=None, parse_constant=None, object_pairs_hook=None, use_decimal=None, parse_eagerly=True, **kw):
+                parse_int=None, parse_constant=None, object_pairs_hook=None, use_decimal=None, parse_eagerly=True,
+                **kw):
     """Deserialize ``fp`` (a file-like object), which contains a text or binary Ion stream, to a Python object using the
     following conversion table::
         +-------------------+-------------------+
@@ -409,6 +401,7 @@ _FROM_ION_TYPE = [
     IonPyDict
 ]
 
+
 def _load_iteratively(reader, end_type=IonEventType.STREAM_END):
     event = reader.send(NEXT_EVENT)
     while event.event_type is not end_type:
@@ -425,8 +418,8 @@ def _load_iteratively(reader, end_type=IonEventType.STREAM_END):
             yield scalar
         event = reader.send(NEXT_EVENT)
 
-def _load(out, reader, end_type=IonEventType.STREAM_END, in_struct=False):
 
+def _load(out, reader, end_type=IonEventType.STREAM_END, in_struct=False):
     def add(obj):
         if in_struct:
             out.add_item(event.field_name.text, obj)
@@ -450,7 +443,8 @@ def _load(out, reader, end_type=IonEventType.STREAM_END, in_struct=False):
 
 
 def loads(ion_str, catalog=None, single_value=True, encoding='utf-8', cls=None, object_hook=None, parse_float=None,
-          parse_int=None, parse_constant=None, object_pairs_hook=None, use_decimal=None, parse_eagerly=True, **kw):
+          parse_int=None, parse_constant=None, object_pairs_hook=None, use_decimal=None, parse_eagerly=True,
+          text_buffer_size_limit=None, **kw):
     """Deserialize ``ion_str``, which is a string representation of an Ion object, to a Python object using the
     conversion table used by load (above).
 
@@ -463,6 +457,9 @@ def loads(ion_str, catalog=None, single_value=True, encoding='utf-8', cls=None,
             ``sequence_as_stream=True``, it must be loaded using ``single_value=False``. Default: True.
         parse_eagerly: (Optional[True|False]) Used in conjunction with ``single_value=False`` to return the result as list
             or an iterator
+        text_buffer_size_limit (int): The maximum byte size allowed for text values when the C extension is enabled
+            (default: 512 bytes). This option only has an effect when the C extension is enabled (and it is enabled by
+            default). When the C extension is disabled, there is no limit on the size of text values.
         encoding: NOT IMPLEMENTED
         cls: NOT IMPLEMENTED
         object_hook: NOT IMPLEMENTED
@@ -480,16 +477,17 @@ def loads(ion_str, catalog=None, single_value=True, encoding='utf-8', cls=None,
             A sequence of Python objects representing a stream of Ion values.
     """
 
-    if isinstance(ion_str, six.binary_type):
+    if isinstance(ion_str, bytes):
         ion_buffer = BytesIO(ion_str)
-    elif isinstance(ion_str, six.text_type):
-        ion_buffer = six.StringIO(ion_str)
+    elif isinstance(ion_str, str):
+        ion_buffer = io.StringIO(ion_str)
     else:
         raise TypeError('Unsupported text: %r' % ion_str)
 
     return load(ion_buffer, catalog=catalog, single_value=single_value, encoding=encoding, cls=cls,
                 object_hook=object_hook, parse_float=parse_float, parse_int=parse_int, parse_constant=parse_constant,
-                object_pairs_hook=object_pairs_hook, use_decimal=use_decimal, parse_eagerly=parse_eagerly)
+                object_pairs_hook=object_pairs_hook, use_decimal=use_decimal, parse_eagerly=parse_eagerly,
+                text_buffer_size_limit=text_buffer_size_limit)
 
 
 def dump_extension(obj, fp, binary=True, sequence_as_stream=False, tuple_as_sexp=False, omit_version_marker=False):
@@ -501,8 +499,21 @@ def dump_extension(obj, fp, binary=True, sequence_as_stream=False, tuple_as_sexp
     fp.write(res)
 
 
-def load_extension(fp, single_value=True, parse_eagerly=True):
-    iterator = ionc.ionc_read(fp, emit_bare_values=False)
+def load_extension(fp, single_value=True, parse_eagerly=True, text_buffer_size_limit=None):
+    """
+    Args:
+        fp (str): A string representation of Ion data.
+        single_value (Optional[True|False]): When True, the data in ``ion_str`` is interpreted as a single Ion value,
+            and will be returned without an enclosing container. If True and there are multiple top-level values in
+            the Ion stream, IonException will be raised. NOTE: this means that when data is dumped using
+            ``sequence_as_stream=True``, it must be loaded using ``single_value=False``. Default: True.
+        parse_eagerly: (Optional[True|False]) Used in conjunction with ``single_value=False`` to return the result as list
+            or an iterator
+        text_buffer_size_limit (int): The maximum byte size allowed for text values when the C extension is enabled
+            (default: 512 bytes). This option only has an effect when the C extension is enabled (and it is enabled by
+            default). When the C extension is disabled, there is no limit on the size of text values.
+    """
+    iterator = ionc.ionc_read(fp, emit_bare_values=False, text_buffer_size_limit=text_buffer_size_limit)
     if single_value:
         try:
             value = next(iterator)
@@ -529,21 +540,23 @@ def dump(obj, fp, imports=None, binary=True, sequence_as_stream=False, skipkeys=
                               tuple_as_sexp=tuple_as_sexp, omit_version_marker=omit_version_marker)
     else:
         return dump_python(obj, fp, imports=imports, binary=binary, sequence_as_stream=sequence_as_stream,
-                         skipkeys=skipkeys, ensure_ascii=ensure_ascii,check_circular=check_circular,
-                         allow_nan=allow_nan, cls=cls, indent=indent, separators=separators, encoding=encoding,
-                         default=default, use_decimal=use_decimal, namedtuple_as_object=namedtuple_as_object,
-                         tuple_as_array=tuple_as_array, bigint_as_string=bigint_as_string, sort_keys=sort_keys,
-                         item_sort_key=item_sort_key, for_json=for_json, ignore_nan=ignore_nan,
-                         int_as_string_bitcount=int_as_string_bitcount, iterable_as_array=iterable_as_array,
-                         tuple_as_sexp=tuple_as_sexp, omit_version_marker=omit_version_marker, **kw)
+                           skipkeys=skipkeys, ensure_ascii=ensure_ascii, check_circular=check_circular,
+                           allow_nan=allow_nan, cls=cls, indent=indent, separators=separators, encoding=encoding,
+                           default=default, use_decimal=use_decimal, namedtuple_as_object=namedtuple_as_object,
+                           tuple_as_array=tuple_as_array, bigint_as_string=bigint_as_string, sort_keys=sort_keys,
+                           item_sort_key=item_sort_key, for_json=for_json, ignore_nan=ignore_nan,
+                           int_as_string_bitcount=int_as_string_bitcount, iterable_as_array=iterable_as_array,
+                           tuple_as_sexp=tuple_as_sexp, omit_version_marker=omit_version_marker, **kw)
 
 
 def load(fp, catalog=None, single_value=True, encoding='utf-8', cls=None, object_hook=None, parse_float=None,
-         parse_int=None, parse_constant=None, object_pairs_hook=None, use_decimal=None, parse_eagerly=True, **kw):
+         parse_int=None, parse_constant=None, object_pairs_hook=None, use_decimal=None, parse_eagerly=True,
+         text_buffer_size_limit=None, **kw):
     if c_ext and catalog is None:
-        return load_extension(fp, parse_eagerly=parse_eagerly, single_value=single_value)
+        return load_extension(fp, parse_eagerly=parse_eagerly, single_value=single_value,
+                              text_buffer_size_limit=text_buffer_size_limit)
     else:
         return load_python(fp, catalog=catalog, single_value=single_value, encoding=encoding, cls=cls,
-                         object_hook=object_hook, parse_float=parse_float, parse_int=parse_int,
-                         parse_constant=parse_constant, object_pairs_hook=object_pairs_hook,
-                         use_decimal=use_decimal, parse_eagerly=parse_eagerly, **kw)
+                           object_hook=object_hook, parse_float=parse_float, parse_int=parse_int,
+                           parse_constant=parse_constant, object_pairs_hook=object_pairs_hook,
+                           use_decimal=use_decimal, parse_eagerly=parse_eagerly, **kw)
