@@ -13,14 +13,7 @@
 # License.
 
 """Provides support for Ion symbol tokens."""
-
-# Python 2/3 compatibility
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-import six
-
+import itertools
 from itertools import chain
 from itertools import islice
 from itertools import repeat
@@ -161,7 +154,7 @@ class SymbolTable(object):
             raise ValueError('Local symbol tables cannot have a name or version')
         if table_type.is_system and (name != TEXT_ION):
             raise ValueError('System symbol tables must be named "%s"' % TEXT_ION)
-        if name is not None and not isinstance(name, six.text_type):
+        if name is not None and not isinstance(name, str):
             raise TypeError('Shared symbol tables must have a unicode name: %r' % name)
 
         self.table_type = table_type
@@ -233,7 +226,7 @@ class SymbolTable(object):
 
     def __add_text(self, text):
         """Adds the given Unicode text as a locally defined symbol."""
-        if text is not None and not isinstance(text, six.text_type):
+        if text is not None and not isinstance(text, str):
             raise TypeError('Local symbol definition must be a Unicode sequence or None: %r' % text)
         sid = self.__new_sid()
         location = None
@@ -257,7 +250,7 @@ class SymbolTable(object):
         """
         if self.table_type.is_shared:
             raise TypeError('Cannot intern on shared symbol table')
-        if not isinstance(text, six.text_type):
+        if not isinstance(text, str):
             raise TypeError('Cannot intern non-Unicode sequence into symbol table: %r' % text)
 
         token = self.get(text)
@@ -281,7 +274,7 @@ class SymbolTable(object):
         Returns:
             SymbolToken: The token associated with the key or the default if it doesn't exist.
         """
-        if isinstance(key, six.text_type):
+        if isinstance(key, str):
             return self.__mapping.get(key, None)
         if not isinstance(key, int):
             raise TypeError('Key must be int or Unicode sequence.')
@@ -360,7 +353,7 @@ class SymbolTable(object):
         other_iter = getattr(other, '__iter__')
         if not callable(other_iter):
             return False
-        for token, other_token in six.moves.zip_longest(self, other):
+        for token, other_token in itertools.zip_longest(self, other):
             if token != other_token:
                 return False
 
@@ -529,7 +522,7 @@ class SymbolTableCatalog(object):
             SymbolTable: The *closest* matching symbol table.  This is either an exact match,
             a placeholder, or a derived substitute depending on what tables are registered.
         """
-        if not isinstance(name, six.text_type):
+        if not isinstance(name, str):
             raise TypeError('Name must be a Unicode sequence: %r' % name)
         if not isinstance(version, int):
             raise TypeError('Version must be an int: %r' % version)
