@@ -11,31 +11,27 @@
 # OF ANY KIND, either express or implied. See the License for the
 # specific language governing permissions and limitations under the
 # License.
-
-# Python 2/3 compatibility
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
+import io
 import struct
+import sys
 from collections import defaultdict
 from decimal import getcontext
+from enum import IntEnum
 from functools import partial
 from io import open, BytesIO
 from itertools import chain
 from os import listdir
 from os.path import isfile, join, abspath, split
 
-import six
 from pytest import raises
 
 from amazon.ion.exceptions import IonException
 from amazon.ion.equivalence import ion_equals
 from amazon.ion.simpleion import load, dump
-from amazon.ion.util import Enum
 from tests import parametrize
 from amazon.ion.simpleion import c_ext
 
+PYPY = hasattr(sys, 'pypy_translation_info')
 
 # This file lives in the tests/ directory. Up one level is tests/ and up another level is the package root, which
 # contains the vectors/ directory.
@@ -95,27 +91,27 @@ def _open(file):
 
 _SKIP_LIST = (
     # TEXT:
-    _good_file(u'subfieldVarUInt.ion'),  # TODO amzn/ion-python#34
-    _good_file(u'subfieldVarUInt32bit.ion'),  # TODO amzn/ion-python#34
-    _good_file(u'whitespace.ion'),  # TODO amzn/ion-python#117
-    _good_file(u'symbols.ion'),  # TODO amzn/ion-python#122
-    _bad_file(u'localSymbolTableWithMultipleImportsFields.ion'),  # TODO amzn/ion-python#118
-    _bad_file(u'localSymbolTableWithMultipleSymbolsAndImportsFields.ion'),  # TODO amzn/ion-python#118
-    _bad_file(u'localSymbolTableWithMultipleSymbolsFields.ion'),  # TODO amzn/ion-python#118
-    _equivs_file(u'localSymbolTableNullSlots.ion'),  # TODO amzn/ion-python#
-    _nonequivs_file(u'symbols.ion'),   # TODO amzn/ion-python#122
-    _nonequivs_file(u'symbolTablesUnknownText.ion'),  # TODO amzn/ion-python#46
+    _good_file(u'subfieldVarUInt.ion'),  # TODO amazon-ion/ion-python#34
+    _good_file(u'subfieldVarUInt32bit.ion'),  # TODO amazon-ion/ion-python#34
+    _good_file(u'whitespace.ion'),  # TODO amazon-ion/ion-python#117
+    _good_file(u'symbols.ion'),  # TODO amazon-ion/ion-python#122
+    _bad_file(u'localSymbolTableWithMultipleImportsFields.ion'),  # TODO amazon-ion/ion-python#118
+    _bad_file(u'localSymbolTableWithMultipleSymbolsAndImportsFields.ion'),  # TODO amazon-ion/ion-python#118
+    _bad_file(u'localSymbolTableWithMultipleSymbolsFields.ion'),  # TODO amazon-ion/ion-python#118
+    _equivs_file(u'localSymbolTableNullSlots.ion'),  # TODO amazon-ion/ion-python#
+    _nonequivs_file(u'symbols.ion'),   # TODO amazon-ion/ion-python#122
+    _nonequivs_file(u'symbolTablesUnknownText.ion'),  # TODO amazon-ion/ion-python#46
 
     # BINARY:
-    _good_file(u'item1.10n'),  # TODO amzn/ion-python#46
-    _good_file(u'nopPadInsideEmptyStructNonZeroSymbolId.10n'),  # TODO amzn/ion-python#120
-    _good_file(u'nopPadInsideStructWithNopPadThenValueNonZeroSymbolId.10n'),  # TODO amzn/ion-python#120
-    _bad_file(u'nopPadWithAnnotations.10n'),  # TODO amzn/ion-python#120
-    _bad_file(u'localSymbolTableWithMultipleImportsFields.10n'),  # TODO amzn/ion-python#118
-    _bad_file(u'localSymbolTableWithMultipleSymbolsAndImportsFields.10n'),  # TODO amzn/ion-python#118
-    _bad_file(u'localSymbolTableWithMultipleSymbolsFields.10n'),  # TODO amzn/ion-python#118
-    _bad_file(u'negativeIntZero.10n'),  # TODO amzn/ion-python#119
-    _equivs_file(u'timestampSuperfluousOffset.10n')  # TODO amzn/ion-python#121
+    _good_file(u'item1.10n'),  # TODO amazon-ion/ion-python#46
+    _good_file(u'nopPadInsideEmptyStructNonZeroSymbolId.10n'),  # TODO amazon-ion/ion-python#120
+    _good_file(u'nopPadInsideStructWithNopPadThenValueNonZeroSymbolId.10n'),  # TODO amazon-ion/ion-python#120
+    _bad_file(u'nopPadWithAnnotations.10n'),  # TODO amazon-ion/ion-python#120
+    _bad_file(u'localSymbolTableWithMultipleImportsFields.10n'),  # TODO amazon-ion/ion-python#118
+    _bad_file(u'localSymbolTableWithMultipleSymbolsAndImportsFields.10n'),  # TODO amazon-ion/ion-python#118
+    _bad_file(u'localSymbolTableWithMultipleSymbolsFields.10n'),  # TODO amazon-ion/ion-python#118
+    _bad_file(u'negativeIntZero.10n'),  # TODO amazon-ion/ion-python#119
+    _equivs_file(u'timestampSuperfluousOffset.10n')  # TODO amazon-ion/ion-python#121
 )
 
 
@@ -124,6 +120,11 @@ if c_ext:
         _good_file(u'subfieldVarInt.ion'),  # c_ext supports 300 decimal digits while here is a 8000+ decimal digits test..
     )
 
+if PYPY:
+    _SKIP_LIST += (
+        _good_file(u'subfieldVarInt.ion'), # amazon-ion/ion-python#229
+        _bad_file(u'ivmInAnnotationWrapper.10n'), # TODO ion-python#230
+    )
 
 if _PLATFORM_ARCHITECTURE == 32:
     _SKIP_LIST += (
@@ -136,7 +137,7 @@ _DEBUG_WHITELIST = (
 )
 
 
-class _VectorType(Enum):
+class _VectorType(IntEnum):
     GOOD = 0
     GOOD_EQUIVS = 2
     GOOD_NONEQUIVS = 3
@@ -291,8 +292,8 @@ def _element_preprocessor(ion_sequence):
     # These strings need to be parsed before comparison.
     def preprocess(element):
         if is_embedded:
-            assert isinstance(element, six.text_type)
-            element = load(six.StringIO(element), single_value=False)
+            assert isinstance(element, str)
+            element = load(io.StringIO(element), single_value=False)
         return element
     is_embedded = ion_sequence.ion_annotations and \
         ion_sequence.ion_annotations[0].text == _embedded_documents_annotation
