@@ -12,17 +12,8 @@
 # specific language governing permissions and limitations under the
 # License.
 
-# Python 2/3 compatibility
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from functools import partial
 
-import six
-import sys
-
-from base64 import b64encode
 from datetime import timedelta, datetime
 from io import BytesIO
 from itertools import chain
